#!/bin/bash

set -ue

source ./config.ini

function main() {
    share_space=$(df -T $share_path |awk  'NR!=1{print $5}' ) 
    cluster_mysql_space=$(df -T $cluster_mysql_datadir | awk  'NR!=1{print $5}' )

    if [ ! -d $cluster_mysql_datadir ]; then
        log error "$cluster_mysql_datadir 不存在"
        exit 1; 
    fi

    if [ $(docker ps |grep  -E "3306" | wc -l) -gt 0 ]; then
        log error "MySQL docker is running.Stop Middleware first."
        exit 1;
    fi


    if [ ${init_server-"false"} = "true" ]; then
        if [ ! -n $init_mysql_datadir ];then
            log error "init mysql datadir not definition. Please check config.ini file."
            exit 1;
        fi

        if [ "$init_mysql_datadir" != "$cluster_mysql_datadir" -a "$(ls -A $cluster_mysql_datadir)" != "" ]; then
            log error "$cluster_mysql_datadir is not empty."
            exit 1 ;
        fi

        [ ! -d $share_mysql_dir ] && mkdir $share_mysql_dir

        mysql_space=$(du -s $init_mysql_datadir | awk '{print $1}')
        if [ $share_space -gt $mysql_space -a $cluster_mysql_space -gt $mysql_space ]; then
            log info "copy mysql data to $share_mysql_dir..."
            cp -rp $init_mysql_datadir/* $share_mysql_dir
            if [ "$init_mysql_datadir" != "$cluster_mysql_datadir" ]; then
                log info "copy mysql data to $cluster_mysql_datadir..."
                cp -rp $init_mysql_datadir/* $cluster_mysql_datadir
            else
                log info "单机数据库文件目录和集群目录相同."
            fi
            log info "$LOCAL_IP mysql is OK."
        else
            log error "共享存储空间不足"
            exit 1;
        fi
    else
        log info "$LOCAL_IP mysql data recovery..."
        if [ ! -d $share_mysql_dir ]; then
            log error "共享存储不存在，请按照顺序执行"
            exit 1;
        fi
        share_mysql_space=$(du -s $share_mysql_dir |awk '{print $1}')
        if [ $cluster_mysql_space -gt $share_mysql_space ]; then
            cp -rp $share_mysql_dir/* $cluster_mysql_datadir
        else
            log error "$cluster_mysql_space 空间不足."
            exit 1;
        fi
        sed -i '2d' $cluster_mysql_datadir/auto.cnf
        sed -i '$aserver-uuid='$(uuidgen)'' $cluster_mysql_datadir/auto.cnf

    fi
}

main
